<template>
  <div class="report-card" v-change-height:report-card-box v-if="!functype">
    <div class="report-card-box">
      <card-group :class="{ 'report-card-group': !card.hide }" v-for="(card, cardIndex) in cardList" :key="cardIndex">
        <!-- 按钮组 -->
        <template v-slot:content>
          <div class="use-report-card" v-if="!card.hide">
            <div class="card-item">
              <!-- 左边 -->
              <div class="card-item-left">
                <!-- 功能标识 -->
                <div class="card-item-left-main">
                  <!-- 图标 -->
                  <div class="card-item-left-main-icon iconfont" :class="`iconfont-${card.icon.key}`" />
                  <div class="card-item-left-main-text">
                    <!-- 卡片名字 -->
                    <p class="card-item-left-main-text-name" v-text="card.name" />
                    <!-- 卡片描述 -->
                    <!-- <p class="card-item-left-main-text-describe" v-text="'贴心好服务'" /> -->
                  </div>
                </div>
              </div>
            </div>
            <div class="card-main">
              <gree-row v-if="!hasOfferElc">
                <gree-col v-for="(item, index) in CardList" :key="index">
                  <div class="card-bg" :style="{ backgroundImage: `url(${require(`@/assets/img/${item.ImgName}.png`)})` }" @click="onClickCard(item.id)">
                    <p class="sum-number">{{ item.total }}<a class="sum-unit" v-text="`${item.unit}`" /></p>
                    <p class="footer-Text" v-html="`${item.footerText}`" />
                  </div>
                </gree-col>
              </gree-row>
              <gree-row v-else>
                <gree-col class="offer-elc-col" v-for="(item, index) in CardList" :key="index">
                  <div
                    class="offer-elc-card"
                    :id="`offer-elc-card-${item.key}`"
                    :style="{ backgroundImage: `url(${require(`@/assets/img/${item.ImgName}.png`)})` }"
                    @click="onClickCard(item.id)"
                  >
                    <p class="sum-offer" v-if="item.key === 'Elc'">{{ Math.round(PVdayTotal) }}<a class="sum-unit" v-text="`${item.unit}`" /></p>
                    <p class="offer-Text" v-html="`${item.footerText1}`" v-if="item.key === 'Elc'" />
                    <gree-divider direction="vertical" v-if="item.key === 'Elc'"></gree-divider>
                    <p class="sum-use" v-if="item.key === 'Elc'">{{ Math.round(dayTotal) }}<a class="sum-unit" v-text="`${item.unit}`" /></p>
                    <p class="use-Text" v-html="`${item.footerText2}`" v-if="item.key === 'Elc'" />
                    <p class="sum-number" v-if="item.key === 'UseTime'">{{ item.total }}<a class="sum-unit" v-text="`${item.unit}`" /></p>
                    <p class="footer-Text" v-html="`${item.footerText}`" v-if="item.key === 'UseTime'" />
                  </div>
                </gree-col>
              </gree-row>
            </div>
          </div>
        </template>
      </card-group>
    </div>
  </div>
</template>

<script>
import { Col, Row, Image, Divider } from 'gree-ui';
import { glyphs } from '@assets/iconfont/iconfont.json';
import BtnGroup from '@/components/BtnGroup/index';
import CardGroup from '@/components/CardGroup/index';
import { mapState, mapGetters, mapMutations } from 'vuex';
import PopupGroup from '@/components/Popup/index';
import temUnChange from '@/mixins/tem';
import { getGridConList, getElecGenerList } from '@PluginInterface';

export default {
  name: 'use-report-card',
  components: {
    [Col.name]: Col,
    [Row.name]: Row,
    [Image.name]: Image,
    [Divider.name]: Divider,
    [BtnGroup.name]: BtnGroup,
    [CardGroup.name]: CardGroup,
    [PopupGroup.name]: PopupGroup
  },
  data() {
    return {
      jsonMap: {
        1: 'CoolSvStTemMin',
        2: 'HumiSvStTemMin',
        4: 'HeatSvStTemMax',
        6: 'Heat3DSvStTemMax',
        7: 'Heat2SvStTemMax'
      }
    };
  },
  mixins: [temUnChange],
  computed: {
    ...mapState('control', {
      mac: state => state.mac,
      Mod: state => state.dataObject.Mod,
      chartData: state => state.chartData,
      total: state => state.chartData.total,
      TemUn: state => state.dataObject.TemUn,
      ElcEn: state => state.dataObject.ElcEn || 0,
      functype: state => state.dataObject.functype,
      totalDays: state => state.chartData.totalDays,
      dayTotal: state => state.chartData.dayTotal || 0,
      HumiEnable: state => state.dataObject.HumiEnable,
      monthTotal: state => state.chartData.monthTotal || 0,
      PVdayTotal: state => state.chartData.PVdayTotal || 0,
      CoolSvStTemMin: state => state.dataObject.CoolSvStTemMin || 18,
      HumiSvStTemMin: state => state.dataObject.HumiSvStTemMin || 18,
      HeatSvStTemMax: state => state.dataObject.HeatSvStTemMax || 18,
      Heat2SvStTemMax: state => state.dataObject.Heat2SvStTemMax || 18,
      Heat3DSvStTemMax: state => state.dataObject.Heat3DSvStTemMax || 18
    }),
    ...mapGetters(['spFuncDefine', 'modTextKey', 'modCurrentStatusName', 'spModCurrentStatusName']),
    ...mapGetters('machine', ['statusMap', 'blindModelArr']),
    cardList() {
      if (!Object.keys(this.statusMap).length) return [];
      const result = this.spFuncDefine.map(model => {
        const identifier = model.identifier;
        if (!this.statusMap[identifier])
          return {
            icon: {},
            handler: () => {
              console.log('Undefined function');
            }
          };
        // 当前status定义
        const status = this.statusMap[identifier].status;
        // 取名称
        const defaultNameKey = `btn.${identifier}`;
        const footerKey = `footer.${identifier}`;
        const describeKey = `describe.${identifier}`;

        const statusNameText = status.name;
        const stateNameText = `${defaultNameKey}_${statusNameText}`;

        const name = stateNameText === this.$language(stateNameText) ? this.$language(defaultNameKey) : this.$language(stateNameText);
        const footer = this.parseStr(footerKey);
        const describe = this.parseStr(describeKey);
        // 图标
        const icon = glyphs.some(item => item.font_class === status.icon.key) ? status.icon : { key: 'undefined', type: 'off' };
        // 是否隐藏
        const hide = this.blindModelArr.includes(identifier);
        // 执行的方法
        const handler = (identifier, disable = false) => {
          disable || this.$stateMachine.nextStatus(identifier);
        };
        return { key: identifier, name, icon, hide, handler, footer, describe };
      });
      return result;
    },
    hasOfferElc() {
      return this.statusMap['OfferElc'];
    },
    CardList() {
      let result = [];
      if (!this.hasOfferElc) {
        // result = [
        //   {
        //     id: 2,
        //     ImgName: 'usetime',
        //     unit: '小时',
        //     total: this.totalDays,
        //     hide: false,
        //     footerText: '您的空调已陪伴您'
        //   }
        // ];
        // if (this.statusMap['ElcEn'] && this.ElcEn === 1) {
        //   result.unshift({
        //     id: 1,
        //     ImgName: 'electric',
        //     unit: '度',
        //     total: this.total,
        //     hide: this.ElcEn,
        //     footerText: '本月空调用电'
        //   });
        // }
        result = [
          {
            id: 1,
            ImgName: 'electric',
            unit: '度',
            total: this.monthTotal,
            hide: this.ElcEn,
            footerText: '本月空调用电'
          }
        ];
      } else {
        result = [
          {
            id: 3,
            unit: '度',
            key: 'Elc',
            hide: this.ElcEn,
            total: this.total,
            ImgName: 'electric',
            footerText1: '今日发电',
            footerText2: '今日用电'
          }
          // {
          //   id: 4,
          //   hide: false,
          //   unit: '小时',
          //   key: 'UseTime',
          //   ImgName: 'usetime',
          //   total: this.totalDays,
          //   footerText: '您的空调已陪伴您'
          // }
        ];
      }
      return result;
    }
  },
  mounted() {
    // this.statusMap['UseReport'] && this.getOverTheYearData();
    this.$bus.$on('getElcData', () => {
      this.getYearData();
    });
    this.$bus.$on('claerData', () => {
      this.getYearData();
    });
    this.ElcEn && this.getYearData();
    this.hasOfferElc && this.getDayData();
  },
  methods: {
    ...mapMutations('control', {
      setChartData: 'SET_CHART_DATA',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    parseStr(str) {
      //  没想好怎么处理，记得改
      if (str === 'describe.SvSt') {
        const { modText } = this;
        // const jsonMap = {
        //   1: 'CoolSvStTemMin',
        //   2: 'HumiSvStTemMin',
        //   4: 'HeatSvStTemMax',
        //   6: 'Heat3DSvStTemMax',
        //   7: 'Heat2SvStTemMax'
        // };
        return this.$language(modText) + this.svstTextList + this[this.jsonMap[this.Mod]] + this.describeUnit;
      }
      return this.$language(str);
    },
    onClickCard(key) {
      if (!this.hasOfferElc) {
        this.$router.push({
          name: 'ReportPage',
          params: {
            id: key
          }
        });
      } else {
        console.log('key-', key);
        this.$router.push({
          name: 'PVReportPage',
          params: {
            id: key
          }
        });
      }
    },
    // getOverTheYearData() {
    //   pluginHttp('/gateway/portrait-recommend/portrait/statistical/overTheYearsReport', '', JSON.stringify({ mac: this.mac }), 'POST', 'iot7', '').then(
    //     _res => {
    //       const yearReport = JSON.parse(_res).data;
    //       const yearData = yearReport.data;
    //       console.log('总报----------------------', yearData);
    //       let result = 0;
    //       Object.values(yearData).forEach(item => {
    //         result = Number(item) + result;
    //         return result;
    //       });
    //       this.setChartData({ totalDays: Math.round(result) });
    //     }
    //   );
    //   // .catch(err => console.error(err));
    // },
    getYearData() {
      getGridConList(this.mac, 'month')
        .then(res => {
          // hideLoading();
          const obj = JSON.parse(res);
          console.log('主页月报-----', obj);
          const { time, val } = obj.data;

          const month = [];
          let TOTAL = 0;
          for (let i = 0; i < time.length; i += 1) {
            month[i] = val[i];
            TOTAL += val[i];
          }
          this.setChartData({ monthTotal: Math.round(TOTAL * 1000) / 1000 });
        })
        .catch(res => {
          console.log('查询失败', res);
        });
    },
    getDayData() {
      getGridConList(this.mac, 'day')
        .then(res => {
          const obj = JSON.parse(res);
          console.log('日用电量-----', obj);
          const { val } = obj.data;

          //  日求和，取最大
          if (val.length > 0) {
            let result = Math.round(val[val.length - 1]);
            this.setChartData({ dayTotal: result });
          }
        })
        .catch(e => {
          console.log('---日用电---查询失败', e);
          showToast('查询失败', 0);
        });
      getElecGenerList(this.mac, 'day')
        .then(_res => {
          const obj = JSON.parse(_res);
          console.log('xxxxx-----日发电量： ', obj);
          const { val } = obj.data;

          //  日求和，取最大
          if (val.length > 0) {
            let result = Math.round(val[val.length - 1]);
            this.setChartData({ PVdayTotal: result });
          }
        })
        .catch(e => {
          console.log('---日发电---查询失败', e);
          showToast('查询失败', 0);
        });
    }
  }
};
</script>

<style lang="scss" scoped>
.report-card {
  position: relative;
  transform: translateZ(1.1);
  .report-card-group {
    padding-bottom: 40px;
    .use-report-card {
      height: 403px;
      width: 100%;
      .card-item {
        // $cardPadding: 30px;
        // height: calc(160px - #{$cardPadding} * 2;
        height: 140px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        align-items: center;
        // padding: $cardPadding 0;
        &-left {
          height: 100%;
          width: 100%;
          display: flex;
          justify-content: space-between;
          align-items: center;
          &-main {
            height: 100%;
            width: 100%;
            margin-left: 20px;
            display: flex;
            justify-content: flex-start;
            align-items: center;
            &-icon {
              $iconHeight: 68px;
              background-image: linear-gradient(180deg, #7fb5f6, #6da4e6);
              height: $iconHeight;
              width: $iconHeight;
              line-height: $iconHeight;
              margin-left: 42px;
              border-radius: 50%;
              font-size: 40px;
              color: #fff;
              text-align: center;
            }
            &-text {
              padding-left: 20px;
              &-name {
                font-size: 48px;
                color: #404657;
                display: inline;
                // &:after {
                //   content: '|';
                //   color: #989898;
                //   opacity: 0.2;
                //   padding-left: 15px;
                //   padding-right: 15px;
                // }
              }
              &-describe {
                color: #989898;
                font-size: 36px;
                display: inline;
              }
              &-footer {
                font-size: 36px;
                color: #989898;
              }
            }
          }
          &::after {
            width: 0px;
          }
        }
        &-right {
          // padding: 0 52px 0 24px;
          width: auto;
          height: 100%;
          display: flex;
          justify-content: flex-start;
          align-items: center;
          &-edit {
            position: absolute;
            right: 58px;
            font-size: 46px;
          }
        }
      }
      .card-main {
        width: 100%;
        height: 390px;
        // display: flex;
        // justify-content: space-around;
        .card-bg {
          width: 440px;
          height: 260px;
          opacity: 1;
          margin-left: 60px;
          margin-right: 25px;
          transform: translateY(-12px);
          background-size: 100% 100%;
          .sum-number {
            position: absolute;
            left: 16px;
            bottom: 84px;
            font-size: 107px;
            color: #fff;
            .sum-unit {
              font-size: 38px;
              color: #fff;
            }
          }
          .footer-Text {
            position: absolute;
            color: #fff;
            font-size: 36px;
            left: 24px;
            bottom: 26px;
          }
        }
        #offer-elc-card-UseTime {
          width: 350px;
          margin-left: 100px;
        }
        .offer-elc-card {
          width: 530px;
          height: 260px;
          margin-left: 50px;
          background-size: 100% 100%;
          transform: translateY(-12px);
        }
        .gree-divider {
          width: 1px;
          height: 87px;
          top: 60px;
          left: 50%;
          opacity: 0.5;
          border-radius: 1px;
        }
        .sum-number {
          left: 16px;
          bottom: 84px;
          color: #fff;
          font-size: 107px;
          position: absolute;
          .sum-unit {
            color: #fff;
            font-size: 38px;
          }
        }
        .footer-Text {
          left: 24px;
          bottom: 26px;
          color: #fff;
          font-size: 36px;
          position: absolute;
        }
        .sum-offer {
          left: 30px;
          bottom: 84px;
          color: #fff;
          font-size: 90px;
          position: absolute;
          .sum-unit {
            color: #fff;
            font-size: 38px;
          }
        }
        .offer-Text {
          left: 30px;
          bottom: 26px;
          color: #fff;
          font-size: 36px;
          position: absolute;
        }
        .sum-use {
          right: 30px;
          bottom: 84px;
          color: #fff;
          font-size: 90px;
          position: absolute;
          .sum-unit {
            color: #fff;
            font-size: 38px;
          }
        }
        .use-Text {
          right: 30px;
          bottom: 26px;
          color: #fff;
          font-size: 36px;
          position: absolute;
        }
      }
    }
  }
}
</style>
